@@ -3,7 +3,7 @@
   SPDX-FileCopyrightText: 2003 Reinhold Kainhofer <reinhold@kainhofer.com>
   SPDX-FileCopyrightText: 2003 Cornelius Schumacher <schumacher@kde.org>
   SPDX-FileCopyrightText: 2008 Ron Goodheart <rong.dev@gmail.com>
-  SPDX-FileCopyrightText: 2010-2022 Laurent Montel <montel@kde.org>
+  SPDX-FileCopyrightText: 2010-2023 Laurent Montel <montel@kde.org>
   SPDX-FileCopyrightText: 2012-2013 Allen Winter <winter@kde.org>
 
   SPDX-License-Identifier: GPL-2.0-or-later WITH Qt-Commercial-exception-1.0
@@ -729,7 +729,6 @@ void CalPrintTimetable::drawTimeTable(QPainter &p, QDate fromDate, QDate toDate,
     QDate curDate(fromDate);
     while (curDate <= toDate) {
         KCalendarCore::Event::List eventList = mCalendar->events(curDate, QTimeZone::systemTimeZone());
-        const auto holidays = holiday(curDate);
         int allDayEvents = holiday(curDate).isEmpty() ? 0 : 1;
         for (const KCalendarCore::Event::Ptr &event : std::as_const(eventList)) {
             Q_ASSERT(event);
@@ -1517,7 +1516,7 @@ void CalPrintTodos::setSettingsWidget()
 
         if (mTodoSortField != TodoFieldUnset) {
             // do not insert if already done so.
-            cfg->mSortField->addItem(i18nc("@option sort by title", "Title"));
+            cfg->mSortField->addItem(i18nc("@option sort by summary", "Summary"));
             cfg->mSortField->addItem(i18nc("@option sort by start date/time", "Start Date"));
             cfg->mSortField->addItem(i18nc("@option sort by due date/time", "Due Date"));
             cfg->mSortField->addItem(i18nc("@option sort by priority", "Priority"));
